package model

import (
	operationPb "kpt-tmr-group/proto/go/backend/operation"
)

type AnalysisAccuracy struct {
	Id                       int64                                 `json:"id"`
	PastureId                int64                                 `json:"pasture_id"`
	PastureName              string                                `json:"pasture_name"`
	FeedFormulaId            int64                                 `json:"feed_formula_id"`
	FeedFormulaName          string                                `json:"feed_formula_name"`
	CattleParentCategoryId   operationPb.CattleCategoryParent_Kind `json:"cattle_parent_category_id"`
	CattleParentCategoryName string                                `json:"cattle_parent_category_name"`
	IWeight                  int64                                 `json:"iweight"`
	LWeight                  int64                                 `json:"lweight"`
	OWeight                  int64                                 `json:"oweight"`
	ActualWeightMinus        int64                                 `json:"actual_weight_minus"`
	AllowRatio               int64                                 `json:"allow_ratio"`
	Alweight                 int64                                 `json:"alweight"`
	DateDay                  string                                `json:"date_day"`
	CreatedAt                int64                                 `json:"created_at"`
	UpdateAt                 int64                                 `json:"update_at"`
}

func (c *AnalysisAccuracy) TableName() string {
	return "analysis_accuracy"
}

type OptionsAnalysisAccuracy struct {
	PastureId            int64  `json:"pasture_id"`
	PastureName          string `json:"pasture_name"`
	AllIweight           int64  `json:"all_iweight"`
	AllLweight           int64  `json:"all_lweight"`
	AllOweight           int64  `json:"all_oweight"`
	AllActualWeightMinus int64  `json:"all_actual_weight_minus"`
	AllAllowRatio        int64  `json:"all_allow_ratio"`
	AllAlweight          int64  `json:"all_alweight"`
	DateDay              string `json:"date_day"`
}

type SearchAnalysisAccuracyResponse struct {
	Code int32                 `json:"code"`
	Msg  string                `json:"msg"`
	Data *AnalysisAccuracyData `json:"data"`
}

type AnalysisAccuracyData struct {
	Chart *Chart `json:"chart"`
	Table *Table `json:"table"`
}

type Table struct {
	TitleList []*TableList   `json:"title_list"`
	DataList  []*interface{} `json:"data_list"`
}

type TableList struct {
	Name  string `json:"name"`
	Value string `json:"value"`
}

type Chart struct {
	MixedFodderAccurateRatio    *CommonValueRatio `json:"mixed_fodder_accurate_ratio"`
	MixedFodderCorrectRatio     *CommonValueRatio `json:"mixed_fodder_correct_ratio"`
	SprinkleFodderAccurateRatio *CommonValueRatio `json:"sprinkle_fodder_accurate_ratio"`
	SprinkleFodderCorrectRatio  *CommonValueRatio `json:"sprinkle_fodder_correct_ratio"`
}

type CommonValueRatio struct {
	MaxValue    string     `json:"max_value"`    // 最高值
	MiddleValue string     `json:"middle_value"` // 中位值
	MinValue    string     `json:"min_value"`    // 最低值
	DataList    [][]string `json:"data_list"`    // 数据集合
	PastureName []string   `json:"pasture_name"` // 牧场名称集合
	PastureIds  []int32    `json:"pasture_ids"`
	DateDay     []string   `json:"date_day"` // 日期集合
}
